// Copyright 2016 CERN and GSI
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <QtGui/QApplication>

#include <silecs-diagnostic/constants.h>
#include <silecs-diagnostic/diagnostictoolmainview.h>
#include <silecs-diagnostic/loginhandler.h>
#include <silecs-diagnostic/silecsmodule.h>


silecsModule *mysilecs;

class I : public QThread
{
public:
        static void sleep(unsigned long secs) {
                QThread::sleep(secs);
        }
};

// Logged in user. (To be set at runtime)
std::string UserName;


    // main with splash screen and login
    int main(int argc, char *argv[])
    {
		mysilecs = NULL;
    	try
    	{
    		Silecs::XMLParser::init();
#ifdef WITH_RBAC
			//Login
			loginHandler* login = new loginHandler();
			if(!login->requestLogin())
			{
				return 0;
			}
#endif

            QApplication app(argc, argv);
			QPixmap pixmap( ":/Images/splash-silecs.png" );

			QSplashScreen splash(pixmap);
			splash.show();

			diagnosticToolMainView mainWin;
			mainWin.setWindowTitle("SILECS Diagnostic Tool");

			if (argc >= 3) // an argument was passed
			{
				if (strcmp(argv[1],"-d") == 0)
					mainWin.setDeployFile(argv[2]);
			}

			I::sleep(SPLASH_SCREEN_TIME);

			mainWin.showMaximized();
			splash.finish(&mainWin);
				return app.exec();
    	}
        catch(std::string *str)
        {
        	std::cout << str;
        }
        catch(std::exception& ex)
        {
        	std::cout << ex.what();
        }
    	catch(...)
    	{
    		std::cout << "Unexpected error caught in Main. Please notify SILECS support";
    	}
        return -1;
    }
